Crate fvm_wasm_instrument

Crate fvm_wasm_instrument 

Modules

gas_metering
This module is used to instrument a Wasm module with gas metering code.
stack_limiter
Contains the code for the stack height limiter instrumentation.